==> geo-xform-1.1.4.tgz: package/lib/shapefile.js <==
/* @flow */
'use strict';

var _ = require('highland');
var fs = require('fs');
var path = require('path');
var child = require('child_process');
var spawn = child.spawn;
var exec = child.exec;
var Cmd = require('./ogr-cmd');

function createStream(options) {
  var lastMessage = undefined;
  var failed = undefined;
  var readStream = _();
  var cmd = Cmd.create('zip', options);
  var ogr = spawn('ogr2ogr', cmd).on('close', function (c) {
    if (c > 0 || failed) readStream.emit('error', new Error('OGR Failed: ' + lastMessage));else {
      var folder = options.path + '/' + options.name;
      if (options.metadata) fs.writeFileSync(folder + '/' + options.name + '.xml', options.metadata);
      createZipStream(folder).on('error', function (e) {
        return readStream.emit('error', e);
      }).pipe(readStream);
    }
  });
  ogr.stderr.on('data', listen);
  function listen(data) {
    var msg = data.toString();
    lastMessage = msg;
    readStream.emit('log', { level: 'error', message: msg });
    if (msg.match(/ERROR\s[^16]/)) {
      failed = true;
      readStream.destroy();
      process.kill(ogr.pid, 'SIGKILL');
    }
  }
  return readStream;
}

function createZipStream(input) {
  var zipStream = _();
  var cmd = ['zip', '-rj', '"' + input + '.zip"', '"' + input + '"', '--exclude=*.json*', '--exclude=*.vrt'];
  renameFiles(input);
  var zip = exec(cmd.join(' '), function (err, stdout, stderr) {
    if (err) return zipStream.emit('error', new Error('Failed while zipping'));
    fs.createReadStream(input + '.zip').pipe(zipStream);
  });
  return zipStream;
}

function renameFiles(input) {
  fs.readdirSync(input).forEach(function (file) {
    var oldName = path.join(input, file);
    var newName = oldName.replace(/ogrgeojson/i, path.basename(input));
    fs.renameSync(oldName, newName);
  });
}

module.exports = { createStream: createStream };

==> geo-xform-1.1.5.tgz: package/lib/shapefile.js <==
/* @flow */
'use strict';

var _ = require('highland');
var fs = require('fs');
var path = require('path');
var child = require('child_process');
var spawn = child.spawn;
var exec = child.exec;
var Cmd = require('./ogr-cmd');

function createStream(options) {
  var lastMessage = undefined;
  var readStream = _();
  var cmd = Cmd.create('zip', options);
  var ogr = spawn('ogr2ogr', cmd).on('close', function (c) {
    if (c > 0) {
      readStream.emit('error', new Error('OGR Failed: ' + lastMessage));
      readStream.destroy();
    } else {
      var folder = options.path + '/' + options.name;
      if (options.metadata) fs.writeFileSync(folder + '/' + options.name + '.xml', options.metadata);
      createZipStream(folder).on('error', function (e) {
        return readStream.emit('error', e);
      }).pipe(readStream);
    }
  });

  _(ogr.stderr).each(function (data) {
    var msg = data.toString();
    lastMessage = msg;
    readStream.emit('log', { level: 'error', message: msg });
    if (msg.match(/ERROR\s[^16]/) || msg.match(/2GB file size limit reached/)) {
      ogr.stderr.unpipe();
      ogr.kill('SIGKILL');
      ogr.emit('close', 1);
    }
  });

  return readStream;
}

function createZipStream(input) {
  var zipStream = _();
  var cmd = ['zip', '-rj', '"' + input + '.zip"', '"' + input + '"', '--exclude=*.json*', '--exclude=*.vrt'];
  renameFiles(input);
  var zip = exec(cmd.join(' '), function (err, stdout, stderr) {
    if (err) return zipStream.emit('error', new Error('Failed while zipping'));
    fs.createReadStream(input + '.zip').pipe(zipStream);
  });
  return zipStream;
}

function renameFiles(input) {
  fs.readdirSync(input).forEach(function (file) {
    var oldName = path.join(input, file);
    var newName = oldName.replace(/ogrgeojson/i, path.basename(input));
    fs.renameSync(oldName, newName);
  });
}

module.exports = { createStream: createStream };
